aboutsummaryrefslogtreecommitdiff
path: root/launcher/InstanceList.cpp
diff options
context:
space:
mode:
authorPetr Mrázek <peterix@gmail.com>2021-10-18 00:47:02 +0200
committerPetr Mrázek <peterix@gmail.com>2021-10-21 00:47:53 +0200
commit5b3dffce62f7e4c00436adeca33c5f2fc4a21db4 (patch)
tree01a0eb2d994a9b0622697a6dbb124966692e692a /launcher/InstanceList.cpp
parent297d4b4196c9bd1d9c4dd422dd88aaec620038d6 (diff)
downloadPrismLauncher-5b3dffce62f7e4c00436adeca33c5f2fc4a21db4.tar.gz
PrismLauncher-5b3dffce62f7e4c00436adeca33c5f2fc4a21db4.tar.bz2
PrismLauncher-5b3dffce62f7e4c00436adeca33c5f2fc4a21db4.zip
NOISSUE continue debranding...
Diffstat (limited to 'launcher/InstanceList.cpp')
-rw-r--r--launcher/InstanceList.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/launcher/InstanceList.cpp b/launcher/InstanceList.cpp
index 42b2ae1a..ae905414 100644
--- a/launcher/InstanceList.cpp
+++ b/launcher/InstanceList.cpp
@@ -259,7 +259,7 @@ void InstanceList::deleteInstance(const InstanceId& id)
return;
}
- qDebug() << "Instance" << id << "has been deleted by MultiMC.";
+ qDebug() << "Instance" << id << "has been deleted by the launcher.";
}
static QMap<InstanceId, InstanceLocator> getIdMapping(const QList<InstancePtr> &list)
@@ -799,7 +799,7 @@ private slots:
private:
/*
* WHY: the whole reason why this uses an exponential backoff retry scheme is antivirus on Windows.
* Basically, it starts messing things up while MultiMC is extracting/creating instances
* and causes that horrible failure that is NTFS to lock files in place because they are open.
*/
ExponentialSeries backoff;
@@ -799,7 +799,7 @@ private slots:
/*
* WHY: the whole reason why this uses an exponential backoff retry scheme is antivirus on Windows.
- * Basically, it starts messing things up while MultiMC is extracting/creating instances
+ * Basically, it starts messing things up while the launcher is extracting/creating instances
* and causes that horrible failure that is NTFS to lock files in place because they are open.
*/